scoretemplatetools.ScoreTemplate
================================

.. inheritance-diagram:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate
   :private-bases:

.. autoclass:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate

Special Methods
---------------

.. automethod:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate.__call__

.. automethod:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate.__eq__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate.__repr__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.scoretemplatetools.ScoreTemplate.ScoreTemplate.ScoreTemplate.__str__

   .. note:: Inherited from `__builtin__.object`
